@@ -11,6 +11,7 @@ from markup import Modules
 from .Processor import Processor
 import sys
 
+
 class MarkdownPP:
     """
     Simplified front-end interface for the Processor and Module systems.
@@ -19,7 +20,7 @@ class MarkdownPP:
     """
 
     def __init__(self, input=None, output=None, modules=None, encoding=None):
-        if encoding == None:
+        if encoding is None:
             encoding = sys.getdefaultencoding()
         pp = Processor(encoding)
 
