@@ -15,6 +15,30 @@ from os import path
 from markup.Module import Module
 from markup.Transform import Transform
 import markup.Markers as Markers
+from markup.Modules.SkipHeaderMetadata import SkipHeaderMetadata
+
+
+skip_header_metadata = SkipHeaderMetadata()
+
+
+def resolve_markdown_link(filepath: str):
+    """
+    if matched link is in markdown format, extract the real path
+    e.g. [describe](real path)
+    """
+    if filepath is None:
+        return None
+
+    if filepath.startswith("[") and filepath.endswith(")") \
+            and "](" in filepath:
+        total_len = len(filepath)
+        pos = filepath.find("](")
+        # print(total_len, pos)
+        # print(filepath[pos + 2:total_len - 1])
+        return filepath[pos + 2:total_len - 1]
+    else:
+        return filepath
+
 
 class Include(Module):
     """
@@ -39,7 +63,7 @@ class Include(Module):
     def transform(self, data):
         transforms = []
         linenum = 0
-        
+
         for line in data:
             match = self.includere.search(line)
             if match:
@@ -57,6 +81,19 @@ class Include(Module):
             original = f.readlines()
             f.close()
 
+            # fitler by excerpt
+            transforms = skip_header_metadata.transform(original)
+            if transforms is None:
+                pass
+            else:
+                transformed_data = []
+                for transform in transforms:
+                    if transform.oper == "noop":
+                        transformed_data.append(original[transform.linenum])
+                if len(transformed_data) > 0:
+                    original = transformed_data
+
+            # filter by skip block markers
             inlcudebeginnum = 0
             inlcudebeginsearch = 0
             for line in original:
@@ -66,7 +103,7 @@ class Include(Module):
                     break
                 else:
                     inlcudebeginsearch = inlcudebeginsearch + 1
-            
+
             data = original[inlcudebeginnum:]
 
             # line by line, apply shift and recursively include file data
@@ -79,7 +116,7 @@ class Include(Module):
                 match = self.includere.search(line)
                 if match:
                     dirname = path.dirname(filename)
-                    data[linenum:linenum+1] = self.include(match, dirname)
+                    data[linenum:linenum + 1] = self.include(match, dirname)
                     includednum = linenum
                     # Update line so that we won't miss a shift if
                     # heading is on the 1st line.
@@ -123,6 +160,8 @@ class Include(Module):
         # print("include fileglob", fileglob)
         shift = int(match.group(3) or 0)
 
+        fileglob = resolve_markdown_link(fileglob)
+
         result = []
 
         if pwd != "":
